@@ -19,7 +19,7 @@ class MainConfig:
     DBFilePath = str(currentPath + r'\FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
-    version = 'FreeTAKServer-1.1'
+    version = 'FreeTAKServer-1.1.1'
 
     # set to None if you don't want a message sent
-    ConnectionMessage = f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'
\ No newline at end of file
+    ConnectionMessage = None
\ No newline at end of file
